==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/tr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Birleşmiş paylaşım",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
    "Remote share" : "Uzak paylaşım",
    "Remote share password" : "Uzak paylaşım parolası",
    "Cancel" : "İptal",
    "Add remote share" : "Uzak paylaşım ekle",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C kullanın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C kullanın.",
    "Invalid Federated Cloud ID" : "Birleşmiş Bulut Kimliği Geçersiz",
    "Server to server sharing is not enabled on this server" : "Bu sunucuda sunucudan sunucuya paylaşım etkin değil",
    "Couldn't establish a federated share." : "Birleşmiş bir paylaşım oluşturulamadı.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Birleşmiş bir paylaşım oluşturulamadı. Parola yanlış olabilir.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Birleşmiş paylaşım isteği gönderildi. Bir çağrı alacaksınız. Bildirimlerinizi denetleyin.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Birleşmiş bir paylaşım oluşturulamadı. Birleşilecek sunucunun sürümü çok eski gibi görünüyor (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Bu sunucudan birleşmiş grup paylaşımları gönderilemez",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$sögesi %2$s ile zaten paylaşılmış olduğundan paylaşılamadı",
    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşmiş paylaşım oluşturulamaz",
    "File is already shared with %s" : "Dosya %s ile zaten paylaşılmış",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s paylaşılamadı. %2$s bulunamadı. Sunucuya erişilemiyor ya da sunucu kendinden imzalı bir güvenlik sertifikası kullanıyor olabilir.",
    "Could not find share" : "Paylaşım bulunamadı",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s kullanıcısından \"%3$s\" uzak paylaşımını aldınız (%2$s adına)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} kullanıcısından {share} uzak paylaşımını aldınız ( {behalf} adına)",
    "You received \"%3$s\" as a remote share from %1$s" : "%1$s kullanıcısından \"%3$s\" uzak paylaşımını aldınız",
    "You received {share} as a remote share from {user}" : "{user} kullanıcısından {share} uzak paylaşımını aldınız",
    "Accept" : "Kabul Et",
    "Decline" : "Reddet",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud Birleşmiş Bulut Kimliğim ile paylaş, %s bölümüne bakın",
    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud Birleşmiş Bulut kimliğim üzerinden benimle paylaş",
    "Sharing" : "Paylaşım",
    "Federated file sharing" : "Birleşmiş dosya paylaşımı",
    "Provide federated file sharing across servers" : "Sunucular arasında birleşmiş dosya paylaşımı sağlar",
    "Federated Cloud Sharing" : "Birleşmiş Bulut Paylaşımı",
    "Open documentation" : "Belgeleri aç",
    "Adjust how people can share between servers." : "Kişilerin sunucular arasında nasıl paylaşım yapabileceğini ayarlayın.",
    "Allow users on this server to send shares to other servers" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin",
    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
    "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
    "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
    "Search global and public address book for users" : "Genel ve herkese açık adres defterinde kullanıcı ara",
    "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
    "Federated Cloud" : "Birleşmiş Bulut",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud, ownCloud ya da Pydio kullanıcıları ile paylaşım yapılaiblir. Yalnızca paylaşım penceresine person@cloud.example.com gibi Birleşmiş Bulut kodunu yazın.",
    "Your Federated Cloud ID:" : "Birleşmiş Bulut Kimliğiniz:",
    "Share it so your friends can share files with you:" : "Paylaşın, böylece arkadaşlarınız da sizinle dosya paylaşabilir:",
    "Add to your website" : "Web sitenize ekleyin",
    "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
    "HTML Code:" : "HTML Kodu:",
    "The mountpoint name contains invalid characters." : "Bağlama noktası adında geçersiz karakterler var.",
    "Not allowed to create a federated share with the owner." : "Sahip ile birleşmiş bir paylaşım oluşturmanıza izin verilmiyor.",
    "Invalid or untrusted SSL certificate" : "Geçersiz ya da güvenilmez SSL sertifikası",
    "Could not authenticate to remote share, password might be wrong" : "Uzak paylaşım kimliği doğrulanamadı. Parola yanlış olabilir",
    "Storage not valid" : "Depolama geçersiz",
    "Federated share added" : "Birleşmiş paylaşım eklendi",
    "Couldn't add remote share" : "Uzak paylaşım eklenemedi",
    "Sharing %s failed, because this item is already shared with %s" : "%s paylaşılmadı. %s ile zaten paylaşılmış",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "%s paylaşılamadı. %s bulunamadı. Sunucuya erişilemiyor ya da sunucu kendinden imzalı bir güvenlik sertifikası kullanıyor olabilir."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/tr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} konumundan {name} uzak paylaşımını eklemek istiyor musunuz?",
    "Remote share" : "Uzak paylaşım",
    "Remote share password" : "Uzak paylaşım parolası",
    "Cancel" : "İptal",
    "Add remote share" : "Uzak paylaşım ekle",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C kullanın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C kullanın.",
    "Invalid Federated Cloud ID" : "Birleşik Bulut Kimliği Geçersiz",
    "Server to server sharing is not enabled on this server" : "Bu sunucuda sunucudan sunucuya paylaşım etkin değil",
    "Couldn't establish a federated share." : "Birleşik bir paylaşım oluşturulamadı.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Birleşik bir paylaşım oluşturulamadı. Parola yanlış olabilir.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Birleşik paylaşım isteği gönderildi. Bir çağrı alacaksınız. Bildirimlerinizi denetleyin.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Birleşik bir paylaşım oluşturulamadı. Birleşik çalışılacak sunucunun sürümü çok eski gibi görünüyor (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Bu sunucudan birleşik grup paylaşımları gönderilemez",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$sögesi %2$s ile zaten paylaşılmış olduğundan paylaşılamadı",
    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
    "File is already shared with %s" : "Dosya %s ile zaten paylaşılmış",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s paylaşılamadı. %2$s bulunamadı. Sunucuya erişilemiyor ya da sunucu kendinden imzalı bir güvenlik sertifikası kullanıyor olabilir.",
    "Could not find share" : "Paylaşım bulunamadı",
    "Federated sharing" : "Birleşik paylaşım",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s kullanıcısından \"%3$s\" uzak paylaşımını aldınız (%2$s adına)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} kullanıcısından {share} uzak paylaşımını aldınız ( {behalf} adına)",
    "You received \"%3$s\" as a remote share from %1$s" : "%1$s kullanıcısından \"%3$s\" uzak paylaşımını aldınız",
    "You received {share} as a remote share from {user}" : "{user} kullanıcısından {share} uzak paylaşımını aldınız",
    "Accept" : "Kabul Et",
    "Decline" : "Reddet",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud Birleşik Bulut Kimliğim ile paylaş, %s bölümüne bakın",
    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud Birleşik Bulut kimliğim üzerinden benimle paylaş",
    "Sharing" : "Paylaşım",
    "Federated file sharing" : "Birleşik dosya paylaşımı",
    "Provide federated file sharing across servers" : "Sunucular arasında birleşik dosya paylaşımı yapılmasını sağlar",
    "Federated Cloud Sharing" : "Birleşik Bulut Paylaşımı",
    "Open documentation" : "Belgeleri aç",
    "Adjust how people can share between servers." : "Kişilerin sunucular arasında nasıl paylaşım yapabileceğini ayarlayın.",
    "Allow users on this server to send shares to other servers" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin",
    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
    "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
    "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
    "Search global and public address book for users" : "Genel ve herkese açık adres defterinde kullanıcı ara",
    "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
    "Federated Cloud" : "Birleşik Bulut",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud ya da Open Cloud Mesh (OCM) ile uyumlu sunucu ve hizmetler ile paylaşım yapılabilir. Paylaşım penceresine person@cloud.example.com gibi Birleşik Bulut kodunu yazmanız yeterlidir.",
    "Your Federated Cloud ID:" : "Birleşik Bulut Kimliğiniz:",
    "Share it so your friends can share files with you:" : "Paylaşın, böylece arkadaşlarınız da sizinle dosya paylaşabilir:",
    "Add to your website" : "Web sitenize ekleyin",
    "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
    "HTML Code:" : "HTML Kodu:",
    "Sharing %s failed, because this item is already shared with %s" : "%s paylaşılmadı. %s ile zaten paylaşılmış",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "%s paylaşılamadı. %s bulunamadı. Sunucuya erişilemiyor ya da sunucu kendinden imzalı bir güvenlik sertifikası kullanıyor olabilir."
},
"nplurals=2; plural=(n > 1);");
